{% extends "payments/base.html" %}

{% block title %}Change Subscription{% endblock title %}

{% block body %}
    {% include "payments/_subscription_status.html" %}
    {% include "payments/_change_plan_form.html" %}
{% endblock %}